@@ -2,9 +2,9 @@
 #define SCRIPT_H
 
 #include <stdbool.h>
-#include <lua.h>
-#include <lualib.h>
-#include <lauxlib.h>
+#include <luajit-2.0/lua.h>
+#include <luajit-2.0/lualib.h>
+#include <luajit-2.0/lauxlib.h>
 #include <unistd.h>
 #include "stats.h"
 #include "wrk.h"
@@ -16,12 +16,14 @@ void script_setup(lua_State *, thread *);
 void script_done(lua_State *, stats *, stats *);
 
 void script_init(lua_State *, thread *, int, char **);
+uint64_t script_delay(lua_State *);
 void script_request(lua_State *, char **, size_t *);
 void script_response(lua_State *, int, buffer *, buffer *);
 size_t script_verify_request(lua_State *L);
 
 bool script_is_static(lua_State *);
 bool script_want_response(lua_State *L);
+bool script_has_delay(lua_State *L);
 bool script_has_done(lua_State *L);
 void script_summary(lua_State *, uint64_t, uint64_t, uint64_t);
 void script_errors(lua_State *, errors *);
